diff --git a/indra/llcommon/llprocess.h b/indra/llcommon/llprocess.h
index 2598f5d985ae5e3a68b0ccf27fe15744e554d0ed..2fb8ef6a5845ddd01068888037411ed244fca451 100644
--- a/indra/llcommon/llprocess.h
+++ b/indra/llcommon/llprocess.h
@@ -470,7 +470,7 @@ class LL_COMMON_API LLProcess: public boost::noncopyable
          * - "len" entire length of pending data, regardless of setLimit()
          * - "slot" this ReadPipe's FILESLOT, e.g. LLProcess::STDOUT
          * - "name" e.g. "stdout"
-         * - "desc" e.g. "SLPlugin (pid) stdout"
+         * - "desc" e.g. "ALPlugin (pid) stdout"
          * - "eof" @c true means there no more data will arrive on this pipe,
          *   therefore no more events on this pump
          *
diff --git a/indra/llfilesystem/lldir_linux.cpp b/indra/llfilesystem/lldir_linux.cpp
index 376457477007b4724fee4351b9a4ce94052c478a..5c13613fff02a613a0d4197e1e23281938596f1d 100644
--- a/indra/llfilesystem/lldir_linux.cpp
+++ b/indra/llfilesystem/lldir_linux.cpp
@@ -267,7 +267,7 @@ bool LLDir_Linux::fileExists(const std::string &filename) const
 /*virtual*/ std::string LLDir_Linux::getLLPluginLauncher()
 {
     return gDirUtilp->getExecutableDir() + gDirUtilp->getDirDelimiter() +
-        "SLPlugin";
+        "ALPlugin";
 }
 
 /*virtual*/ std::string LLDir_Linux::getLLPluginFilename(std::string base_name)
diff --git a/indra/llfilesystem/lldir_mac.cpp b/indra/llfilesystem/lldir_mac.cpp
index 16f96ddf8bcb0acabfab73553b9e7a9605010619..c4a6e4d89ae3b530ba258de3d0a34acdb97baadb 100644
--- a/indra/llfilesystem/lldir_mac.cpp
+++ b/indra/llfilesystem/lldir_mac.cpp
@@ -147,7 +147,7 @@ LLDir_Mac::LLDir_Mac()
 
         mWorkingDir = getCurPath();
 
-        mLLPluginDir = mAppRODataDir + mDirDelimiter + "SLPlugin.app" + mDirDelimiter + "Contents" + mDirDelimiter + "Frameworks";
+        mLLPluginDir = mAppRODataDir + mDirDelimiter + "ALPlugin.app" + mDirDelimiter + "Contents" + mDirDelimiter + "Frameworks";
     }
 }
 
@@ -182,7 +182,7 @@ bool LLDir_Mac::fileExists(const std::string &filename) const
 /*virtual*/ std::string LLDir_Mac::getLLPluginLauncher()
 {
     return gDirUtilp->getAppRODataDir() + gDirUtilp->getDirDelimiter() +
-        "SLPlugin.app/Contents/MacOS/SLPlugin";
+        "ALPlugin.app/Contents/MacOS/ALPlugin";
 }
 
 /*virtual*/ std::string LLDir_Mac::getLLPluginFilename(std::string base_name)
diff --git a/indra/llfilesystem/lldir_win32.cpp b/indra/llfilesystem/lldir_win32.cpp
index faf7d5147dbc6962685ef35a092b444124332d98..70978a39ec43cf8fd116027296e57ad476042246 100644
--- a/indra/llfilesystem/lldir_win32.cpp
+++ b/indra/llfilesystem/lldir_win32.cpp
@@ -394,7 +394,7 @@ bool LLDir_Win32::fileExists(const std::string& filename) const
 /*virtual*/ std::string LLDir_Win32::getLLPluginLauncher()
 {
     return gDirUtilp->getExecutableDir() + gDirUtilp->getDirDelimiter() +
-        "SLPlugin.exe";
+        "ALPlugin.exe";
 }
 
 /*virtual*/ std::string LLDir_Win32::getLLPluginFilename(std::string base_name)
diff --git a/indra/llplugin/slplugin/CMakeLists.txt b/indra/llplugin/slplugin/CMakeLists.txt
index 2dc5ba89d7df2e8de30fe51ba80df223ae72d4ba..fce83115783256eb4fc8b6114e9b3fa99ae62b47 100644
--- a/indra/llplugin/slplugin/CMakeLists.txt
+++ b/indra/llplugin/slplugin/CMakeLists.txt
@@ -1,4 +1,4 @@
-project(SLPlugin)
+project(ALPlugin)
 
 include(00-Common)
 include(LLCommon)
@@ -24,13 +24,13 @@ if (SLPlugin_HEADER_FILES)
   list(APPEND SLPlugin_SOURCE_FILES ${SLPlugin_HEADER_FILES})
 endif (SLPlugin_HEADER_FILES)
 
-add_executable(SLPlugin
+add_executable(ALPlugin
     WIN32
     MACOSX_BUNDLE
     ${SLPlugin_SOURCE_FILES}
     )
 
-target_link_libraries(SLPlugin
+target_link_libraries(ALPlugin
         PUBLIC
         llplugin
         llmessage
@@ -39,19 +39,19 @@ target_link_libraries(SLPlugin
         )
 
 if (WINDOWS)
-  set_target_properties(SLPlugin
+  set_target_properties(ALPlugin
     PROPERTIES
     LINK_FLAGS_DEBUG "/NODEFAULTLIB:\"LIBCMTD\""
     )
 elseif (LINUX)
-  set_target_properties(SLPlugin 
+  set_target_properties(ALPlugin 
     PROPERTIES
     LINK_FLAGS "-Wl,--disable-new-dtags"
     SKIP_BUILD_RPATH FALSE
     BUILD_WITH_INSTALL_RPATH TRUE
     INSTALL_RPATH "$ORIGIN/../lib;$ORIGIN/llplugin")
 elseif (DARWIN)
-  set_target_properties(SLPlugin
+  set_target_properties(ALPlugin
     PROPERTIES
     BUILD_WITH_INSTALL_RPATH 1
     INSTALL_RPATH "@executable_path/../../../../Frameworks;@executable_path/../Frameworks;@executable_path/../Frameworks/plugins"
@@ -61,10 +61,10 @@ elseif (DARWIN)
 
   # Make sure the app bundle has a Resources directory (it will get populated by viewer-manifest.py later)
   add_custom_command(
-    TARGET SLPlugin POST_BUILD
+    TARGET ALPlugin POST_BUILD
     COMMAND mkdir
     ARGS
       -p
-      ${CMAKE_CURRENT_BINARY_DIR}/$<IF:$<BOOL:${LL_GENERATOR_IS_MULTI_CONFIG}>,$<CONFIG>,>/SLPlugin.app/Contents/Resources
+      ${CMAKE_CURRENT_BINARY_DIR}/$<IF:$<BOOL:${LL_GENERATOR_IS_MULTI_CONFIG}>,$<CONFIG>,>/ALPlugin.app/Contents/Resources
   )
 endif ()
diff --git a/indra/llplugin/slplugin/slplugin.cpp b/indra/llplugin/slplugin/slplugin.cpp
index f23edc3534a2922560b936a541e7c61aa4ce6b20..ebdf236029f070fee90fe5aed9ff7ff09f23f82f 100644
--- a/indra/llplugin/slplugin/slplugin.cpp
+++ b/indra/llplugin/slplugin/slplugin.cpp
@@ -169,7 +169,7 @@ int main(int argc, char **argv)
 #if LL_WINDOWS
     if( strlen( lpCmdLine ) == 0 )
     {
-        LL_ERRS("slplugin") << "usage: " << "SLPlugin" << " launcher_port" << LL_ENDL;
+        LL_ERRS("slplugin") << "usage: " << "ALPlugin" << " launcher_port" << LL_ENDL;
     };
 
     U32 port = 0;
diff --git a/indra/media_plugins/cef/media_plugin_cef.cpp b/indra/media_plugins/cef/media_plugin_cef.cpp
index 46a16f5d669d57432feb317fd4e93db518f7eefb..a64c07964cbfeeabaeae12e37107c03dbb958c97 100644
--- a/indra/media_plugins/cef/media_plugin_cef.cpp
+++ b/indra/media_plugins/cef/media_plugin_cef.cpp
@@ -648,7 +648,7 @@ void MediaPluginCEF::receiveMessage(const char* message_string)
 #if LL_WINDOWS
                 // As of CEF version 83+, for Windows versions, we need to tell CEF
                 // where the host helper process is since this DLL is not in the same
-                // dir as the executable that loaded it (SLPlugin.exe). The code in
+                // dir as the executable that loaded it (ALPlugin.exe). The code in
                 // Dullahan that tried to figure out the location automatically uses
                 // the location of the exe which isn't helpful so we tell it explicitly.
                 settings.host_process_path = mHelperPath;
diff --git a/indra/newview/CMakeLists.txt b/indra/newview/CMakeLists.txt
index bbbadd05231edc8fb5eca91f7ebbe468ccca878f..527dc856ee1335352e5c59b11a95d986dc4739b0 100644
--- a/indra/newview/CMakeLists.txt
+++ b/indra/newview/CMakeLists.txt
@@ -1949,7 +1949,7 @@ if (WINDOWS)
       ${CMAKE_CURRENT_SOURCE_DIR}/licenses-win32.txt
       ${CMAKE_CURRENT_SOURCE_DIR}/featuretable.txt
       ${viewer_APPSETTINGS_FILES}
-      SLPlugin
+      ALPlugin
       media_plugin_example
       )
 
@@ -2026,7 +2026,7 @@ if (WINDOWS)
       add_dependencies(${VIEWER_BINARY_NAME} copy_win_scripts)
     endif (EXISTS ${CMAKE_SOURCE_DIR}/copy_win_scripts)
 
-    add_dependencies(${VIEWER_BINARY_NAME} SLPlugin)
+    add_dependencies(${VIEWER_BINARY_NAME} ALPlugin)
 
     # sets the 'working directory' for debugging from visual studio.
     # Condition for version can be moved to requirements once build agents will be updated (see TOOL-3865)
@@ -2209,7 +2209,7 @@ if (LINUX)
   # These are the generated targets that are copied to package/
   set(COPY_INPUT_DEPENDENCIES
     ${VIEWER_BINARY_NAME}
-    SLPlugin
+    ALPlugin
     media_plugin_example
     media_plugin_libvlc
     )
@@ -2361,7 +2361,7 @@ if (DARWIN)
       ${CMAKE_CURRENT_SOURCE_DIR}/viewer_manifest.py
     )
 
-  add_dependencies(${VIEWER_BINARY_NAME} SLPlugin)
+  add_dependencies(${VIEWER_BINARY_NAME} ALPlugin)
 
   if (USE_CEF)
       add_dependencies(${VIEWER_BINARY_NAME} media_plugin_cef)
diff --git a/indra/newview/viewer_manifest.py b/indra/newview/viewer_manifest.py
index 70f9337fcd455333e9c07fcf03ca4259a64d7d48..e4e1224c2cd5dcde7e0c8d0a9df5c5483ab8291b 100755
--- a/indra/newview/viewer_manifest.py
+++ b/indra/newview/viewer_manifest.py
@@ -451,7 +451,7 @@ def construct(self):
         # Plugin host application
         self.path2basename(os.path.join(os.pardir,
                                         'llplugin', 'slplugin', self.args['configuration']),
-                           "slplugin.exe")
+                           "ALPlugin.exe")
         
         # Get shared libs from the shared libs staging directory
         with self.prefix(src=os.path.join(self.args['build'], os.pardir,
@@ -863,7 +863,7 @@ def construct(self):
 
                 # our apps
                 executable_path = {}
-                embedded_apps = [ (os.path.join("llplugin", "slplugin"), "SLPlugin.app") ]
+                embedded_apps = [ (os.path.join("llplugin", "slplugin"), "ALPlugin.app") ]
                 for app_bld_dir, app in embedded_apps:
                     self.path2basename(os.path.join(os.pardir,
                                                     app_bld_dir, self.args['configuration']),
@@ -878,8 +878,8 @@ def construct(self):
                         for libfile in dylibs:
                             self.relsymlinkf(os.path.join(libfile_parent, libfile))
 
-                # Dullahan helper apps go inside SLPlugin.app
-                with self.prefix(dst=os.path.join("SLPlugin.app", "Contents", "Frameworks")):
+                # Dullahan helper apps go inside ALPlugin.app
+                with self.prefix(dst=os.path.join("ALPlugin.app", "Contents", "Frameworks")):
                     # copy CEF plugin
                     self.path2basename("../media_plugins/cef/" + self.args['configuration'],
                                        "media_plugin_cef.dylib")
@@ -924,7 +924,7 @@ def package_finish(self):
                 pass
             else:
                 # variable found so use it to unlock keychain followed by codesign
-                slplugin_path = os.path.join(application, "Contents", "Resources", "SLPlugin.app")
+                slplugin_path = os.path.join(application, "Contents", "Resources", "ALPlugin.app")
                 home_path = os.environ['HOME']
                 viewer_keychain = os.path.join(home_path, 'Library',
                                                 'Keychains', keychain_name)
@@ -1124,7 +1124,7 @@ def construct(self):
 
         with self.prefix(dst="bin"):
             self.path("alchemy-bin","do-not-directly-run-alchemy-bin")
-            self.path2basename("../llplugin/slplugin", "SLPlugin")
+            self.path2basename("../llplugin/alplugin", "ALPlugin")
             #this copies over the python wrapper script, associated utilities and required libraries, see SL-321, SL-322 and SL-323
             #with self.prefix(src="../viewer_components/manager", dst=""):
             #    self.path("*.py")